@@ -1,30 +1,69 @@
 package Apache::PAR::Registry;
-
-use 5.005;
 use strict;
 use warnings;
 
 require Exporter;
 use vars qw(@ISA %EXPORT_TAGS @EXPORT_OK @EXPORT $VERSION);
-@ISA = qw(Exporter Apache::PAR::ScriptBase Apache::RegistryNG);
-
 %EXPORT_TAGS = ( 'all' => [ qw( ) ] );
 
 @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 @EXPORT = qw( );
 
-$VERSION = '0.02';
+$VERSION = '.10';
+@ISA = qw(Exporter);
 
-use Apache::RegistryNG;
-use Apache::Constants qw(:common);
-use Apache::PAR::ScriptBase;
+if(eval "Apache::exists_config_define('MODPERL2')") {
+	@ISA = qw(Exporter Apache::PAR::RegistryCooker);
+	require Apache::PAR::RegistryCooker;
+	require Apache::Const;
+	import Apache::Const qw(OK);
+}
+else {
+	@ISA = qw(Exporter Apache::PAR::ScriptBase Apache::RegistryNG);
+	require Apache::RegistryNG;
+	require Apache::PAR::ScriptBase;
+	require Apache::Constants;
+	import Apache::Constants qw(OK);
+}
+
+
+my $parent = 'Apache::PAR::RegistryCooker';
+
+my %aliases = (
+	new             => 'new',
+	init            => 'init',
+	default_handler => 'default_handler',
+	run             => 'run',
+	make_namespace  => 'make_namespace',
+	namespace_root  => 'namespace_root',
+	is_cached       => 'is_cached',
+	should_compile  => 'should_compile_if_modified',
+	flush_namespace => 'NOP',
+	cache_table     => 'cache_table_common',
+	cache_it        => 'cache_it',
+	rewrite_shebang => 'rewrite_shebang',
+	chdir_file      => 'chdir_file_normal',
+	get_mark_line   => 'get_mark_line',
+	compile         => 'compile',
+	error_check     => 'error_check',
+	strip_end_data_segment             => 'strip_end_data_segment',
+	convert_script_to_compiled_handler => 'convert_script_to_compiled_handler',
+	can_compile     => $parent . '::can_PAR_compile',
+	read_script     => $parent . '::read_PAR_script',
+	set_script_name => $parent . '::set_PAR_script_name',
+	namespace_from  => $parent . '::namespace_from_PAR',
+);
+
+if(eval "Apache::exists_config_define('MODPERL2')") {
+	__PACKAGE__->install_aliases(\%aliases);
+}
 
 sub can_compile {
 	my $pr = shift;
 
 	my $status = $pr->SUPER::can_compile();
-	return $status unless $status eq OK;
+	return $status unless $status eq OK();
 	return $pr->_can_compile();
 }
 
@@ -34,7 +73,7 @@ sub namespace_from {
 
 sub run {
 	my $pr = shift;
-	$pr->_set_path_info();	
+	$pr->_set_path_info();
 	return $pr->SUPER::run();
 }
 
@@ -59,7 +98,7 @@ A sample configuration (within a web.conf) is below:
 
 =head1 DESCRIPTION
 
-Subclass of Apache::Registry to serve Apache::Registry scripts to clients from within .par files.  Registry scripts should continue to operate as they did before when inside a .par archive.
+Subclass of Apache::Registry (or ModPerl::Registry) to serve Apache::Registry scripts to clients from within .par files.  Registry scripts should continue to operate as they did before when inside a .par archive.
 
 To use, add Apache::PAR::Registry into the Apache configuration, either through an Apache configuration file, or through a web.conf file (discussed in more detail in the Apache::PAR manpage.)
 
@@ -90,7 +129,7 @@ Nathan Byrd, E<lt>nathan@byrd.netE<gt>
 
 L<perl>.
 
-L<PAR>, L<Apache::PAR>, and L<Apache::Registry>.
+L<PAR>, L<Apache::PAR>, and L<Apache::Registry> or L<ModPerl::Registry>.
 
 =head1 COPYRIGHT
 
